@@ -153,12 +153,12 @@ int main(int argc, char** argv) {
 	}
 	
 	microfeed_main = microfeed_main_new();
-	subscriber = microfeed_subscriber_new("org.microfeed.Utils.Subscriber", "/org/microfeed/Utils/Subscriber", microfeed_main_get_dbus_connection(microfeed_main));
+	subscriber = microfeed_subscriber_new("org.microfeed.Utils.Subscriber", microfeed_main_get_dbus_connection(microfeed_main));
 	if (argc == 2) {
-		microfeed_subscriber_subscribe_feed(subscriber, argv[1], MICROFEED_FEED_URI_OVERVIEW, &callbacks, feed_subscribed, microfeed_main);
+		microfeed_subscriber_subscribe_feed(subscriber, argv[1], MICROFEED_FEED_URI_OVERVIEW, &callbacks, microfeed_main, feed_subscribed, microfeed_main);
 	} else {
 		for (i = 1; i + 1 < argc; i += 2) {
-			microfeed_subscriber_subscribe_feed(subscriber, argv[i], argv[i + 1], &callbacks, feed_subscribed, microfeed_main);
+			microfeed_subscriber_subscribe_feed(subscriber, argv[i], argv[i + 1], &callbacks, microfeed_main, feed_subscribed, microfeed_main);
 		}	
 	}
 	microfeed_main_loop(microfeed_main);
